/*
	ExampleEditor.java
*/
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import com.elsid.trellis.*;

public class ExampleEditor extends BaseModule
{
	boolean was_edited = false;
	JTextArea text_area = null;
	String MODULE_TITLE = "Editor";
	String UNKNOWN_FILE = "unknown";
	
	String current_name = UNKNOWN_FILE;
	
	// Constructors
	
	public ExampleEditor( Trellis base_gui )
	{
		// This is required 
		super( base_gui );
	
		setTitle( MODULE_TITLE + " : " + current_name );		
		setSize( 400, 200 );
	
		getContentPane().setLayout( new BorderLayout() );
	
		text_area = new JTextArea( "" );
		text_area.setTabSize( 4 );
		getContentPane().add( "Center", new JScrollPane( text_area ));
		
		// Enable Base Menu Elements
		
		initMenuBar();
		
		// enable Base Toolbar Elements
		
		initToolBar();
		
		text_area.addKeyListener( new KeyAdapter()
		{
			public void keyPressed( KeyEvent e )
			{
				was_edited = true;
			}
		});
		
		setVisible( true );
	}
	
	// Public Methods
	// Overloaded from super class
	
	public void doClose()
	{
		setVisible( false );
		dispose();
	}
	
	public void doNew()
	{
		if( was_edited )
			doSave(); 
		text_area.setText( "" );
	}
		
	public void doOpen()
	{
		FileData fd;
		
		fd = doOpenReadText( "*" );
		if ( fd != null )
		{
			current_name = fd.getName();
			text_area.setText( fd.getData() );
			setTitle( MODULE_TITLE + " : " + current_name );
		}					
	}
	
	public void doSave()
	{
		int mode;
		
		if ( current_name.equals( UNKNOWN_FILE ) )
			mode = Trellis.SAVE_AS;
		else
			mode = Trellis.SAVE;
			
		if( doSaveWriteText( current_name, text_area.getText(), mode  ) )
			was_edited = false;
	}
	
	public void doSaveAs()
	{
		if( doSaveWriteText( "*", text_area.getText(),	Trellis.SAVE_AS ) )
			was_edited = false;
	}
	
	public void doCopy()
	{
		String str = null;
		
		str = text_area.getSelectedText();
		if( str != null && str.length() > 0 )
			setClipboardString( str );
	}
	
	public void doCut()
	{
		String str = null;
		
		str = text_area.getSelectedText();
		if ( str != null && str.length() > 0 )
		{
			setClipboardString( str );
			text_area.replaceRange( "", text_area.getSelectionStart(), text_area.getSelectionEnd() );
			was_edited = true;
		}	
	}
	
	public void doPaste()
	{
		String str = null;
		
		if ( (str = getClipboardString()) != null )
		{
			text_area.insert( getClipboardString(), text_area.getSelectionStart() );
			was_edited = true;
		}
	}
	
}